==> vala-0.2.0.tar.gz: vala-0.2.0/vala/valaerrortype.c <==
/* valaerrortype.vala
 *
 * Copyright (C) 2008  Jürg Billeter
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.

 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.

 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA
 *
 * Author:
 * 	Jürg Billeter <j@bitron.ch>
 *	Raffaele Sandrini <raffaele@sandrini.ch>
 */

#include <vala/valaerrortype.h>
#include <vala/valacodenode.h>
#include <vala/valasourcefile.h>
#include <vala/valacodecontext.h>
#include <vala/valanamespace.h>
#include <vala/valascope.h>




struct _ValaErrorTypePrivate {
	ValaErrorDomain* _error_domain;
};
#define VALA_ERROR_TYPE_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALA_TYPE_ERROR_TYPE, ValaErrorTypePrivate))
enum  {
	VALA_ERROR_TYPE_DUMMY_PROPERTY,
	VALA_ERROR_TYPE_ERROR_DOMAIN
};
static gboolean vala_error_type_real_compatible (ValaDataType* base, ValaDataType* target_type, gboolean enable_non_null);
static char* vala_error_type_real_to_string (ValaCodeNode* base);
static ValaDataType* vala_error_type_real_copy (ValaDataType* base);
static char* vala_error_type_real_get_cname (ValaDataType* base, gboolean var_type, gboolean const_type);
static char* vala_error_type_real_get_lower_case_cname (ValaDataType* base, const char* infix);
static gboolean vala_error_type_real_equals (ValaDataType* base, ValaDataType* type2);
static ValaSymbol* vala_error_type_real_get_member (ValaDataType* base, const char* member_name);
static gpointer vala_error_type_parent_class = NULL;
static void vala_error_type_dispose (GObject * obj);



ValaErrorType* vala_error_type_new (ValaErrorDomain* error_domain, ValaSourceReference* source_reference) {
	ValaErrorType * self;
	g_return_val_if_fail (error_domain == NULL || VALA_IS_ERROR_DOMAIN (error_domain), NULL);
	g_return_val_if_fail (source_reference == NULL || VALA_IS_SOURCE_REFERENCE (source_reference), NULL);
	self = g_object_newv (VALA_TYPE_ERROR_TYPE, 0, NULL);
	vala_error_type_set_error_domain (self, error_domain);
	vala_data_type_set_data_type (VALA_DATA_TYPE (self), VALA_TYPESYMBOL (error_domain));
	vala_code_node_set_source_reference (VALA_CODE_NODE (self), source_reference);
	return self;
}


static gboolean vala_error_type_real_compatible (ValaDataType* base, ValaDataType* target_type, gboolean enable_non_null) {
	ValaErrorType * self;
	ValaErrorType* _tmp1;
	ValaDataType* _tmp0;
	ValaErrorType* et;
	gboolean _tmp4;
	self = VALA_ERROR_TYPE (base);
	g_return_val_if_fail (target_type == NULL || VALA_IS_DATA_TYPE (target_type), FALSE);
	_tmp1 = NULL;
	_tmp0 = NULL;
	et = (_tmp1 = (_tmp0 = target_type, (VALA_IS_ERROR_TYPE (_tmp0) ? ((ValaErrorType*) _tmp0) : NULL)), (_tmp1 == NULL ? NULL : g_object_ref (_tmp1)));
	/* error types are only compatible to error types */
	if (et == NULL) {
		gboolean _tmp2;
		return (_tmp2 = FALSE, (et == NULL ? NULL : (et = (g_object_unref (et), NULL))), _tmp2);
	}
	/* every error type is compatible to the base error type */
	if (et->priv->_error_domain == NULL) {
		gboolean _tmp3;
		return (_tmp3 = TRUE, (et == NULL ? NULL : (et = (g_object_unref (et), NULL))), _tmp3);
	}
	return (_tmp4 = et->priv->_error_domain == self->priv->_error_domain, (et == NULL ? NULL : (et = (g_object_unref (et), NULL))), _tmp4);
}


/* otherwhise the error_domain has to be equal */
static char* vala_error_type_real_to_string (ValaCodeNode* base) {
	ValaErrorType * self;
	self = VALA_ERROR_TYPE (base);
	if (self->priv->_error_domain == NULL) {
		return g_strdup ("GLib.Error");
	} else {
		return vala_symbol_get_full_name (VALA_SYMBOL (self->priv->_error_domain));
	}
}


static ValaDataType* vala_error_type_real_copy (ValaDataType* base) {
	ValaErrorType * self;
	self = VALA_ERROR_TYPE (base);
	return VALA_DATA_TYPE (vala_error_type_new (self->priv->_error_domain, vala_code_node_get_source_reference (VALA_CODE_NODE (self))));
}


static char* vala_error_type_real_get_cname (ValaDataType* base, gboolean var_type, gboolean const_type) {
	ValaErrorType * self;
	self = VALA_ERROR_TYPE (base);
	return g_strdup ("GError*");
}


static char* vala_error_type_real_get_lower_case_cname (ValaDataType* base, const char* infix) {
	ValaErrorType * self;
	self = VALA_ERROR_TYPE (base);
	if (self->priv->_error_domain == NULL) {
		if (infix == NULL) {
			return g_strdup ("g_error");
		} else {
			return g_strdup_printf ("g_%s_error", infix);
		}
	} else {
		return vala_symbol_get_lower_case_cname (VALA_SYMBOL (self->priv->_error_domain), infix);
	}
}


static gboolean vala_error_type_real_equals (ValaDataType* base, ValaDataType* type2) {
	ValaErrorType * self;
	ValaErrorType* _tmp1;
	ValaDataType* _tmp0;
	ValaErrorType* et;
	gboolean _tmp3;
	self = VALA_ERROR_TYPE (base);
	g_return_val_if_fail (type2 == NULL || VALA_IS_DATA_TYPE (type2), FALSE);
	_tmp1 = NULL;
	_tmp0 = NULL;
	et = (_tmp1 = (_tmp0 = type2, (VALA_IS_ERROR_TYPE (_tmp0) ? ((ValaErrorType*) _tmp0) : NULL)), (_tmp1 == NULL ? NULL : g_object_ref (_tmp1)));
	if (et == NULL) {
		gboolean _tmp2;
		return (_tmp2 = FALSE, (et == NULL ? NULL : (et = (g_object_unref (et), NULL))), _tmp2);
	}
	return (_tmp3 = self->priv->_error_domain == et->priv->_error_domain, (et == NULL ? NULL : (et = (g_object_unref (et), NULL))), _tmp3);
}


static ValaSymbol* vala_error_type_real_get_member (ValaDataType* base, const char* member_name) {
	ValaErrorType * self;
	ValaNamespace* _tmp0;
	ValaNamespace* root_symbol;
	ValaSymbol* _tmp1;
	ValaSymbol* _tmp2;
	ValaSymbol* gerror_symbol;
	ValaSymbol* _tmp3;
	self = VALA_ERROR_TYPE (base);
	_tmp0 = NULL;
	root_symbol = (_tmp0 = vala_code_context_get_root (vala_source_file_get_context (vala_source_reference_get_file (vala_code_node_get_source_reference (VALA_CODE_NODE (self))))), (_tmp0 == NULL ? NULL : g_object_ref (_tmp0)));
	_tmp1 = NULL;
	_tmp2 = NULL;
	gerror_symbol = (_tmp2 = vala_scope_lookup (vala_symbol_get_scope ((_tmp1 = vala_scope_lookup (vala_symbol_get_scope (VALA_SYMBOL (root_symbol)), "GLib"))), "Error"), (_tmp1 == NULL ? NULL : (_tmp1 = (g_object_unref (_tmp1), NULL))), _tmp2);
	_tmp3 = NULL;
	return (_tmp3 = vala_scope_lookup (vala_symbol_get_scope (gerror_symbol), member_name), (root_symbol == NULL ? NULL : (root_symbol = (g_object_unref (root_symbol), NULL))), (gerror_symbol == NULL ? NULL : (gerror_symbol = (g_object_unref (gerror_symbol), NULL))), _tmp3);
}


ValaErrorDomain* vala_error_type_get_error_domain (ValaErrorType* self) {
	g_return_val_if_fail (VALA_IS_ERROR_TYPE (self), NULL);
	return self->priv->_error_domain;
}


void vala_error_type_set_error_domain (ValaErrorType* self, ValaErrorDomain* value) {
	g_return_if_fail (VALA_IS_ERROR_TYPE (self));
	self->priv->_error_domain = value;
}


static void vala_error_type_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
	ValaErrorType * self;
	self = VALA_ERROR_TYPE (object);
	switch (property_id) {
		case VALA_ERROR_TYPE_ERROR_DOMAIN:
		g_value_set_object (value, vala_error_type_get_error_domain (self));
		break;
		default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
		break;
	}
}


static void vala_error_type_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
	ValaErrorType * self;
	self = VALA_ERROR_TYPE (object);
	switch (property_id) {
		case VALA_ERROR_TYPE_ERROR_DOMAIN:
		vala_error_type_set_error_domain (self, g_value_get_object (value));
		break;
		default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
		break;
	}
}


static void vala_error_type_class_init (ValaErrorTypeClass * klass) {
	vala_error_type_parent_class = g_type_class_peek_parent (klass);
	g_type_class_add_private (klass, sizeof (ValaErrorTypePrivate));
	G_OBJECT_CLASS (klass)->get_property = vala_error_type_get_property;
	G_OBJECT_CLASS (klass)->set_property = vala_error_type_set_property;
	G_OBJECT_CLASS (klass)->dispose = vala_error_type_dispose;
	VALA_DATA_TYPE_CLASS (klass)->compatible = vala_error_type_real_compatible;
	VALA_CODE_NODE_CLASS (klass)->to_string = vala_error_type_real_to_string;
	VALA_DATA_TYPE_CLASS (klass)->copy = vala_error_type_real_copy;
	VALA_DATA_TYPE_CLASS (klass)->get_cname = vala_error_type_real_get_cname;
	VALA_DATA_TYPE_CLASS (klass)->get_lower_case_cname = vala_error_type_real_get_lower_case_cname;
	VALA_DATA_TYPE_CLASS (klass)->equals = vala_error_type_real_equals;
	VALA_DATA_TYPE_CLASS (klass)->get_member = vala_error_type_real_get_member;
	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_ERROR_TYPE_ERROR_DOMAIN, g_param_spec_object ("error-domain", "error-domain", "error-domain", VALA_TYPE_ERROR_DOMAIN, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
}


static void vala_error_type_init (ValaErrorType * self) {
	self->priv = VALA_ERROR_TYPE_GET_PRIVATE (self);
}


static void vala_error_type_dispose (GObject * obj) {
	ValaErrorType * self;
	self = VALA_ERROR_TYPE (obj);
	G_OBJECT_CLASS (vala_error_type_parent_class)->dispose (obj);
}


GType vala_error_type_get_type (void) {
	static GType vala_error_type_type_id = 0;
	if (G_UNLIKELY (vala_error_type_type_id == 0)) {
		static const GTypeInfo g_define_type_info = { sizeof (ValaErrorTypeClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_error_type_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaErrorType), 0, (GInstanceInitFunc) vala_error_type_init };
		vala_error_type_type_id = g_type_register_static (VALA_TYPE_REFERENCE_TYPE, "ValaErrorType", &g_define_type_info, 0);
	}
	return vala_error_type_type_id;
}

==> vala-0.3.2.tar.gz: vala-0.3.2/vala/valaerrortype.c <==
/* valaerrortype.vala
 *
 * Copyright (C) 2008  Jürg Billeter
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.

 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.

 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA
 *
 * Author:
 * 	Jürg Billeter <j@bitron.ch>
 *	Raffaele Sandrini <raffaele@sandrini.ch>
 */

#include <vala/valaerrortype.h>
#include <vala/valacodenode.h>
#include <vala/valasourcefile.h>
#include <vala/valacodecontext.h>
#include <vala/valanamespace.h>
#include <vala/valascope.h>




struct _ValaErrorTypePrivate {
	ValaErrorDomain* _error_domain;
};

#define VALA_ERROR_TYPE_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALA_TYPE_ERROR_TYPE, ValaErrorTypePrivate))
enum  {
	VALA_ERROR_TYPE_DUMMY_PROPERTY,
	VALA_ERROR_TYPE_ERROR_DOMAIN
};
static gboolean vala_error_type_real_compatible (ValaDataType* base, ValaDataType* target_type);
static char* vala_error_type_real_to_string (ValaCodeNode* base);
static ValaDataType* vala_error_type_real_copy (ValaDataType* base);
static char* vala_error_type_real_get_cname (ValaDataType* base);
static char* vala_error_type_real_get_lower_case_cname (ValaDataType* base, const char* infix);
static gboolean vala_error_type_real_equals (ValaDataType* base, ValaDataType* type2);
static ValaSymbol* vala_error_type_real_get_member (ValaDataType* base, const char* member_name);
static char* vala_error_type_real_get_type_id (ValaDataType* base);
static gpointer vala_error_type_parent_class = NULL;
static void vala_error_type_dispose (GObject * obj);



ValaErrorType* vala_error_type_new (ValaErrorDomain* error_domain, ValaSourceReference* source_reference) {
	ValaErrorType * self;
	g_return_val_if_fail (error_domain == NULL || VALA_IS_ERROR_DOMAIN (error_domain), NULL);
	g_return_val_if_fail (source_reference == NULL || VALA_IS_SOURCE_REFERENCE (source_reference), NULL);
	self = g_object_newv (VALA_TYPE_ERROR_TYPE, 0, NULL);
	vala_error_type_set_error_domain (self, error_domain);
	vala_data_type_set_data_type (VALA_DATA_TYPE (self), VALA_TYPESYMBOL (error_domain));
	vala_code_node_set_source_reference (VALA_CODE_NODE (self), source_reference);
	return self;
}


static gboolean vala_error_type_real_compatible (ValaDataType* base, ValaDataType* target_type) {
	ValaErrorType * self;
	ValaErrorType* _tmp2;
	ValaDataType* _tmp1;
	ValaErrorType* et;
	gboolean _tmp5;
	self = VALA_ERROR_TYPE (base);
	g_return_val_if_fail (VALA_IS_DATA_TYPE (target_type), FALSE);
	/* temporarily ignore type parameters */
	if (vala_data_type_get_type_parameter (target_type) != NULL) {
		return TRUE;
	}
	_tmp2 = NULL;
	_tmp1 = NULL;
	et = (_tmp2 = (_tmp1 = target_type, (VALA_IS_ERROR_TYPE (_tmp1) ? ((ValaErrorType*) _tmp1) : NULL)), (_tmp2 == NULL ? NULL : g_object_ref (_tmp2)));
	/* error types are only compatible to error types */
	if (et == NULL) {
		gboolean _tmp3;
		return (_tmp3 = FALSE, (et == NULL ? NULL : (et = (g_object_unref (et), NULL))), _tmp3);
	}
	/* every error type is compatible to the base error type */
	if (et->priv->_error_domain == NULL) {
		gboolean _tmp4;
		return (_tmp4 = TRUE, (et == NULL ? NULL : (et = (g_object_unref (et), NULL))), _tmp4);
	}
	/* otherwhise the error_domain has to be equal */
	return (_tmp5 = et->priv->_error_domain == self->priv->_error_domain, (et == NULL ? NULL : (et = (g_object_unref (et), NULL))), _tmp5);
}


static char* vala_error_type_real_to_string (ValaCodeNode* base) {
	ValaErrorType * self;
	self = VALA_ERROR_TYPE (base);
	if (self->priv->_error_domain == NULL) {
		return g_strdup ("GLib.Error");
	} else {
		return vala_symbol_get_full_name (VALA_SYMBOL (self->priv->_error_domain));
	}
}


static ValaDataType* vala_error_type_real_copy (ValaDataType* base) {
	ValaErrorType * self;
	self = VALA_ERROR_TYPE (base);
	return VALA_DATA_TYPE (vala_error_type_new (self->priv->_error_domain, vala_code_node_get_source_reference (VALA_CODE_NODE (self))));
}


static char* vala_error_type_real_get_cname (ValaDataType* base) {
	ValaErrorType * self;
	self = VALA_ERROR_TYPE (base);
	return g_strdup ("GError*");
}


static char* vala_error_type_real_get_lower_case_cname (ValaDataType* base, const char* infix) {
	ValaErrorType * self;
	self = VALA_ERROR_TYPE (base);
	if (self->priv->_error_domain == NULL) {
		if (infix == NULL) {
			return g_strdup ("g_error");
		} else {
			return g_strdup_printf ("g_%s_error", infix);
		}
	} else {
		return vala_symbol_get_lower_case_cname (VALA_SYMBOL (self->priv->_error_domain), infix);
	}
}


static gboolean vala_error_type_real_equals (ValaDataType* base, ValaDataType* type2) {
	ValaErrorType * self;
	ValaErrorType* _tmp1;
	ValaDataType* _tmp0;
	ValaErrorType* et;
	gboolean _tmp3;
	self = VALA_ERROR_TYPE (base);
	g_return_val_if_fail (VALA_IS_DATA_TYPE (type2), FALSE);
	_tmp1 = NULL;
	_tmp0 = NULL;
	et = (_tmp1 = (_tmp0 = type2, (VALA_IS_ERROR_TYPE (_tmp0) ? ((ValaErrorType*) _tmp0) : NULL)), (_tmp1 == NULL ? NULL : g_object_ref (_tmp1)));
	if (et == NULL) {
		gboolean _tmp2;
		return (_tmp2 = FALSE, (et == NULL ? NULL : (et = (g_object_unref (et), NULL))), _tmp2);
	}
	return (_tmp3 = self->priv->_error_domain == et->priv->_error_domain, (et == NULL ? NULL : (et = (g_object_unref (et), NULL))), _tmp3);
}


static ValaSymbol* vala_error_type_real_get_member (ValaDataType* base, const char* member_name) {
	ValaErrorType * self;
	ValaNamespace* _tmp0;
	ValaNamespace* root_symbol;
	ValaSymbol* _tmp1;
	ValaSymbol* _tmp2;
	ValaSymbol* gerror_symbol;
	ValaSymbol* _tmp3;
	self = VALA_ERROR_TYPE (base);
	g_return_val_if_fail (member_name != NULL, NULL);
	_tmp0 = NULL;
	root_symbol = (_tmp0 = vala_code_context_get_root (vala_source_file_get_context (vala_source_reference_get_file (vala_code_node_get_source_reference (VALA_CODE_NODE (self))))), (_tmp0 == NULL ? NULL : g_object_ref (_tmp0)));
	_tmp1 = NULL;
	_tmp2 = NULL;
	gerror_symbol = (_tmp2 = vala_scope_lookup (vala_symbol_get_scope ((_tmp1 = vala_scope_lookup (vala_symbol_get_scope (VALA_SYMBOL (root_symbol)), "GLib"))), "Error"), (_tmp1 == NULL ? NULL : (_tmp1 = (g_object_unref (_tmp1), NULL))), _tmp2);
	_tmp3 = NULL;
	return (_tmp3 = vala_scope_lookup (vala_symbol_get_scope (gerror_symbol), member_name), (root_symbol == NULL ? NULL : (root_symbol = (g_object_unref (root_symbol), NULL))), (gerror_symbol == NULL ? NULL : (gerror_symbol = (g_object_unref (gerror_symbol), NULL))), _tmp3);
}


static char* vala_error_type_real_get_type_id (ValaDataType* base) {
	ValaErrorType * self;
	self = VALA_ERROR_TYPE (base);
	return g_strdup ("G_TYPE_POINTER");
}


ValaErrorDomain* vala_error_type_get_error_domain (ValaErrorType* self) {
	g_return_val_if_fail (VALA_IS_ERROR_TYPE (self), NULL);
	return self->priv->_error_domain;
}


void vala_error_type_set_error_domain (ValaErrorType* self, ValaErrorDomain* value) {
	g_return_if_fail (VALA_IS_ERROR_TYPE (self));
	self->priv->_error_domain = value;
}


static void vala_error_type_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
	ValaErrorType * self;
	self = VALA_ERROR_TYPE (object);
	switch (property_id) {
		case VALA_ERROR_TYPE_ERROR_DOMAIN:
		g_value_set_object (value, vala_error_type_get_error_domain (self));
		break;
		default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
		break;
	}
}


static void vala_error_type_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
	ValaErrorType * self;
	self = VALA_ERROR_TYPE (object);
	switch (property_id) {
		case VALA_ERROR_TYPE_ERROR_DOMAIN:
		vala_error_type_set_error_domain (self, g_value_get_object (value));
		break;
		default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
		break;
	}
}


static void vala_error_type_class_init (ValaErrorTypeClass * klass) {
	vala_error_type_parent_class = g_type_class_peek_parent (klass);
	g_type_class_add_private (klass, sizeof (ValaErrorTypePrivate));
	G_OBJECT_CLASS (klass)->get_property = vala_error_type_get_property;
	G_OBJECT_CLASS (klass)->set_property = vala_error_type_set_property;
	G_OBJECT_CLASS (klass)->dispose = vala_error_type_dispose;
	VALA_DATA_TYPE_CLASS (klass)->compatible = vala_error_type_real_compatible;
	VALA_CODE_NODE_CLASS (klass)->to_string = vala_error_type_real_to_string;
	VALA_DATA_TYPE_CLASS (klass)->copy = vala_error_type_real_copy;
	VALA_DATA_TYPE_CLASS (klass)->get_cname = vala_error_type_real_get_cname;
	VALA_DATA_TYPE_CLASS (klass)->get_lower_case_cname = vala_error_type_real_get_lower_case_cname;
	VALA_DATA_TYPE_CLASS (klass)->equals = vala_error_type_real_equals;
	VALA_DATA_TYPE_CLASS (klass)->get_member = vala_error_type_real_get_member;
	VALA_DATA_TYPE_CLASS (klass)->get_type_id = vala_error_type_real_get_type_id;
	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_ERROR_TYPE_ERROR_DOMAIN, g_param_spec_object ("error-domain", "error-domain", "error-domain", VALA_TYPE_ERROR_DOMAIN, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
}


static void vala_error_type_init (ValaErrorType * self) {
	self->priv = VALA_ERROR_TYPE_GET_PRIVATE (self);
}


static void vala_error_type_dispose (GObject * obj) {
	ValaErrorType * self;
	self = VALA_ERROR_TYPE (obj);
	G_OBJECT_CLASS (vala_error_type_parent_class)->dispose (obj);
}


GType vala_error_type_get_type (void) {
	static GType vala_error_type_type_id = 0;
	if (G_UNLIKELY (vala_error_type_type_id == 0)) {
		static const GTypeInfo g_define_type_info = { sizeof (ValaErrorTypeClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_error_type_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaErrorType), 0, (GInstanceInitFunc) vala_error_type_init };
		vala_error_type_type_id = g_type_register_static (VALA_TYPE_REFERENCE_TYPE, "ValaErrorType", &g_define_type_info, 0);
	}
	return vala_error_type_type_id;
}
